# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEcsListArgs',
    'InstanceEcsListArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceEcsListArgsDict(TypedDict):
        ecs_id: NotRequired[pulumi.Input[builtins.str]]
        """
        The ID of the ECS instance.
        """
elif False:
    InstanceEcsListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEcsListArgs:
    def __init__(__self__, *,
                 ecs_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] ecs_id: The ID of the ECS instance.
        """
        if ecs_id is not None:
            pulumi.set(__self__, "ecs_id", ecs_id)

    @property
    @pulumi.getter(name="ecsId")
    def ecs_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the ECS instance.
        """
        return pulumi.get(self, "ecs_id")

    @ecs_id.setter
    def ecs_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ecs_id", value)


