# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOidcProvidersProviderResult',
]

@pulumi.output_type
class GetOidcProvidersProviderResult(dict):
    def __init__(__self__, *,
                 arn: builtins.str,
                 client_ids: Sequence[builtins.str],
                 create_time: builtins.str,
                 description: builtins.str,
                 fingerprints: Sequence[builtins.str],
                 id: builtins.str,
                 issuance_limit_time: builtins.int,
                 issuer_url: builtins.str,
                 oidc_provider_name: builtins.str,
                 update_time: builtins.str):
        """
        :param builtins.str arn: ARN of OIDC identity provider.
        :param Sequence[builtins.str] client_ids: Client ID.
        :param builtins.str create_time: Creation Time (UTC time).
        :param builtins.str description: Description of OIDC identity provider.
        :param Sequence[builtins.str] fingerprints: The authentication fingerprint of the HTTPS CA certificate.
        :param builtins.str id: The ID of the resource supplied above.
        :param builtins.int issuance_limit_time: The earliest time when an external IdP is allowed to issue an ID Token. If the iat field in the ID Token is greater than the current time, the request is rejected.Unit: hours. Value range: 1~168.
        :param builtins.str issuer_url: The issuer URL of the OIDC identity provider.
        :param builtins.str oidc_provider_name: The name of the OIDC identity provider.
        :param builtins.str update_time: Modification Time (UTC time).
        """
        pulumi.set(__self__, "arn", arn)
        pulumi.set(__self__, "client_ids", client_ids)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "fingerprints", fingerprints)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "issuance_limit_time", issuance_limit_time)
        pulumi.set(__self__, "issuer_url", issuer_url)
        pulumi.set(__self__, "oidc_provider_name", oidc_provider_name)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter
    def arn(self) -> builtins.str:
        """
        ARN of OIDC identity provider.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="clientIds")
    def client_ids(self) -> Sequence[builtins.str]:
        """
        Client ID.
        """
        return pulumi.get(self, "client_ids")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Creation Time (UTC time).
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of OIDC identity provider.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def fingerprints(self) -> Sequence[builtins.str]:
        """
        The authentication fingerprint of the HTTPS CA certificate.
        """
        return pulumi.get(self, "fingerprints")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the resource supplied above.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="issuanceLimitTime")
    def issuance_limit_time(self) -> builtins.int:
        """
        The earliest time when an external IdP is allowed to issue an ID Token. If the iat field in the ID Token is greater than the current time, the request is rejected.Unit: hours. Value range: 1~168.
        """
        return pulumi.get(self, "issuance_limit_time")

    @property
    @pulumi.getter(name="issuerUrl")
    def issuer_url(self) -> builtins.str:
        """
        The issuer URL of the OIDC identity provider.
        """
        return pulumi.get(self, "issuer_url")

    @property
    @pulumi.getter(name="oidcProviderName")
    def oidc_provider_name(self) -> builtins.str:
        """
        The name of the OIDC identity provider.
        """
        return pulumi.get(self, "oidc_provider_name")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        Modification Time (UTC time).
        """
        return pulumi.get(self, "update_time")


